import java.io.*;
import java.util.logging.*;

/**
 * Writes an Alignment object to an alignment xml file.
 * @author darko
 *
 */
public class AlignmentWriter {
	Logger logger = Logger.getLogger(AlignmentWriter.class.getName());

	protected PrintStream stream;
	protected Alignment alignment;

	public AlignmentWriter(PrintStream out, Alignment alignment) {
		this.stream = out;
		this.alignment = alignment;
	}

	public AlignmentWriter(File file, Alignment alignment) {
		try {
			this.stream = new PrintStream(file);
			this.alignment = alignment;
		} catch (Exception ex) {
			logger.severe(ex.toString());
			ex.printStackTrace();
			throw new RuntimeException();
		}
	}

	public AlignmentWriter(String filename, Alignment alignment) {
		this(new File(filename), alignment);
	}

	public PrintStream getStream() {
		return this.stream;
	}

	public void setStream(PrintStream stream) {
		this.stream = stream;
	}

	public void setStream(String filename) {
		try {
			this.setStream(new PrintStream(filename));
		} catch (Exception ex) {
			logger.severe(ex.toString());
			ex.printStackTrace();
			throw new RuntimeException();
		}
	}

	public Alignment getAlignment() {
		return this.alignment;
	}

	public void setAlignment(Alignment alignment) {
		this.alignment = alignment;
	}

	public void write() {
		stream.println("<?xml version=\"1.0\" encoding=\"us-ascii\"?>");
		stream.println("<!DOCTYPE cesAlign SYSTEM \"xcesAlign.dtd\">");
		stream.println("<cesAlign version=\"4.1\">");

		stream.println("\t<linkList id=\"" + alignment.name + "\">");
		String domains = "";
		for (Corpus corpus : alignment.corpora) {
			domains += corpus.name + " ";
		}
		domains = domains.trim();
		stream.println("\t\t<linkGrp id=\"" + alignment.name + ".1\" type=\"body\" targType=\"s\" domains=\"" + domains + "\">");

		for (Link link : alignment.links) {
			String linkLine = "";
			linkLine += "\t\t\t<link xtargets=\"";
			linkLine += link.toString();
			linkLine += "\"/>";

			if (link.cardinality != null) {
				linkLine += "\t<!--" + link.cardinality + "-->";
			}

			if (!link.isEmpty()) {
				stream.println(linkLine);
			}

		}

		stream.println("\t\t</linkGrp>");
		stream.println("\t</linkList>");
		stream.println("</cesAlign>");

		stream.flush();
	}

}
